==> owncloud-10.0.3.tgz: owncloud/lib/l10n/hr.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Pisanje u \"config\" direktoriju nije moguće!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ovo se obično može popraviti tako da se Web poslužitelju dopusti pristup za pisanje u config direktoriju",
    "See %s" : "Vidite %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ovo se obično može popraviti %sdavanjem pristupa web poslužitelju za pisanje u config direktoriju%s.",
    "Sample configuration detected" : "Nađena ogledna konfiguracija",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Otkriveno je da je ogledna konfiguracija kopirana. To može vašu instalaciju prekinuti i nije podržano.Molimo pročitajte dokumentaciju prije nego li izvršite promjene na config.php",
    "PHP %s or higher is required." : "PHP verzija treba biti %s ili viša.",
    "PHP with a version lower than %s is required." : "PHP sa verzijom manjom od %s je potrebna.",
    "Following databases are supported: %s" : "Sljedece baza podataka je podrzana: %s",
    "The library %s is not available." : "Knjiznica %s nije dostupna.",
    "Following platforms are supported: %s" : "Sljedece platforme su podrzane: %s",
    "ownCloud %s or higher is required." : "ownCloud %s ili visi je potreban.",
    "Unknown filetype" : "Vrsta datoteke nepoznata",
    "Invalid image" : "Neispravna slika",
    "today" : "Danas",
    "yesterday" : "Jučer",
    "last month" : "Prošli mjesec",
    "_%n month ago_::_%n months ago_" : ["prije %n mjeseca","prije %n mjeseci","prije %n mjeseci"],
    "last year" : "Prošle godine",
    "_%n hour ago_::_%n hours ago_" : ["prije %n sata","prije %n sati","prije %n sati"],
    "_%n minute ago_::_%n minutes ago_" : ["prije %n minute","prije %n minuta","prije %n minuta"],
    "seconds ago" : "prije par sekundi",
    "None" : "Ništa",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "App directory already exists" : "Direktorij aplikacije već postoji",
    "Can't create app folder. Please fix permissions. %s" : "Nije moguće kreirati mapu aplikacija. molimo popravite dozvole. %s",
    "No source specified when installing app" : "Pri instaliranju aplikacija nijedan izvor nije specificiran",
    "No href specified when installing app from http" : "Pri instaliranju aplikacija iz http nijedan href nije specificiran.",
    "No path specified when installing app from local file" : "Pri instaliranju aplikacija iz lokalne datoteke nijedan put nije specificiran.",
    "Archives of type %s are not supported" : "Arhive tipa %s nisu podržane",
    "Failed to open archive when installing app" : "Otvaranje arhive pri instaliranju aplikacija nije uspjelo.",
    "App does not provide an info.xml file" : "Aplikacija ne pruža info.xml datoteku",
    "App can't be installed because of not allowed code in the App" : "Aplikaciju nije moguće instalirati zbog nedopuštenog koda u njoj.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikaciju nije moguće instalirati jer nije kompatibilna s ovom verzijom ownClouda.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikaciju nije moguće instalirati jer sadrži oznaku <otpremljeno>istinito</otpremljeno>.",
    "Apps" : "Aplikacije",
    "General" : "Općenito",
    "Security" : "Sigurnost",
    "Encryption" : "Šifriranje",
    "Sharing" : "Dijeljenje zajedničkih resursa",
    "Search" : "pretraži",
    "Updates" : "nadogradnje",
    "%s enter the database username." : "%s unesite naziva korisnika baze podataka.",
    "%s enter the database name." : "%s unesite naziv baze podataka",
    "%s you may not use dots in the database name" : "%s ne smijete koristiti točke u nazivu baze podataka",
    "Oracle connection could not be established" : "Vezu Oracle nije moguće uspostaviti",
    "Oracle username and/or password not valid" : "Korisničko ime i/ili lozinka Oracle neispravni",
    "DB Error: \"%s\"" : "DB pogreška: \"%s\"",
    "Offending command was: \"%s\"" : "Neispravna naredba je bila: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Trebate unijeti neki postojeći račun ili administratora.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Neispravna naredba je bila: \"%s\", ime: %s, lozinka: %s",
    "PostgreSQL username and/or password not valid" : "Korisničko ime i/ili lozinka PostgreSQL neispravni",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba.",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najbolje rezultate, molimo razmotrite mogućnost korištenje poslužitelja GNU/Linux.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Molimo uklonite postavke za open_basedir setting iz datoteke php.ini ili se prebacite na 64-bitni PHP.",
    "Set an admin username." : "Navedite admin korisničko ime.",
    "Set an admin password." : "Navedite admin lozinku.",
    "Can't create or write into the data directory %s" : "Ne moze se kreirati ili napisati u imenik podataka %s",
    "%s shared »%s« with you" : "%s je s vama podijelio »%s«",
    "Sharing %s failed, because the file does not exist" : "Dijeljenje %s nije uspjelo jer ta datoteka ne postoji",
    "You are not allowed to share %s" : "Nije vam dopušteno dijeliti %s",
    "Sharing %s failed, because the user %s does not exist" : "Dijeljenje %s nije uspjelo jer korisnik %s ne postoji",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Dijeljenje %s nije uspjelo jer korisnik %s nije član niti jedne grupe u kojoj je %s član",
    "Sharing %s failed, because this item is already shared with %s" : "Dijeljenje %s nije uspjelo jer je ova stavka već podijeljena s %s",
    "Sharing %s failed, because the group %s does not exist" : "Dijeljenje %s nije uspjelo jer grupa %s ne postoji",
    "Sharing %s failed, because %s is not a member of the group %s" : "Dijeljenje %s nije uspjelo jer %s nije član grupe %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Da biste kreirali javnu vezu, morate navesti lozinku, samo zaštićene veze su dopuštene.",
    "Sharing %s failed, because sharing with links is not allowed" : "Dijeljenje %s nije uspjelo jer dijeljenje s vezama nije dopušteno.",
    "Share type %s is not valid for %s" : "Tip dijeljenja %s nije dopušteni tip za %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Postavke dozvola za %s nisu uspjele jer dozvole premašuju dozvole za koje %s ima odobrenje",
    "Setting permissions for %s failed, because the item was not found" : "Postavke dozvola za %s nisu uspjele jer stavka nije nađena.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nije moguće postaviti datum isteka. Nakon što su podijeljeni, resursi ne mogu isteći kasnije nego %s ",
    "Cannot set expiration date. Expiration date is in the past" : "Nije moguće postaviti datum isteka. Datum isteka je u prošlosti",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Dijeljenje pozadine %s mora implementirati sučelje OCP\\Share_Backend",
    "Sharing backend %s not found" : "Dijeljenje pozadine %s nije nađeno",
    "Sharing backend for %s not found" : "Dijeljenje pozadine za %s nije nađeno",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Dijeljenje %s nije uspjelo jer dozvole premašuju dozvole za koje %s ima odobrenje.",
    "Sharing %s failed, because resharing is not allowed" : "Dijeljenje %s nije uspjelo jer ponovno dijeljenje nije dopušteno.",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Dijeljenje %s nije uspjelo jer pozadina za %s nije mogla pronaći svoj izvor",
    "Sharing %s failed, because the file could not be found in the file cache" : "Dijeljenje %s nije uspjelo jer u predmemoriji datoteke datoteka nije nađena.",
    "Could not find category \"%s\"" : "Kategorija \"%s\" nije nađena",
    "A valid username must be provided" : "Nužno je navesti ispravno korisničko ime",
    "A valid password must be provided" : "Nužno je navesti ispravnu lozinku",
    "The username is already being used" : "Korisničko ime se već koristi",
    "Help" : "Pomoć",
    "Settings" : "Postavke",
    "Users" : "Korisnici",
    "web services under your control" : "web usluge pod vašom kontrolom",
    "Application is not enabled" : "Aplikacija nije aktivirana",
    "Authentication error" : "Pogrešna autentikacija",
    "Token expired. Please reload page." : "Token je istekao. Molimo, ponovno učitajte stranicu.",
    "Unknown user" : "Korisnik nepoznat",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Pogonski programi baze podataka (sqlite, mysql, ili postgresql) nisu instalirani.",
    "Cannot write into \"config\" directory" : "Nije moguće zapisivati u \"config\" direktorij",
    "Cannot write into \"apps\" directory" : "Nije moguće zapisivati u \"apps\" direktorij",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ovo se obično može popraviti %sdavanjem pristupa web poslužitelju za pisanje u apps direktorij%sili isključivanjem appstorea u konfiguracijskoj datoteci.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Dozvole se obično mogu popraviti %sdavanjem pristupa web poslužitelju za pisanje u korijenskom direktoriju%s",
    "Setting locale to %s failed" : "Postavljanje regionalne sheme u %s nije uspjelo",
    "Please install one of these locales on your system and restart your webserver." : "Molimo instalirajte jednu od ovih regionalnih shema u svoj sustav i ponovno pokrenite svoj web poslužitelj.",
    "Please ask your server administrator to install the module." : "Molimo zamolite svog administratora poslužitelja da instalira modul.",
    "PHP module %s not installed." : "PHP modul %s nije instaliran.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemoriranja kao što je Zend OPcache ilieAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduli su instalirani, ali još uvijek su na popisu onih koji nedostaju?",
    "Please ask your server administrator to restart the web server." : "Molimo zamolite  svog administratora poslužitelja da ponovno pokrene web poslužitelj.",
    "PostgreSQL >= 9 required" : "Potreban je PostgreSQL >= 9",
    "Please upgrade your database version" : "Molimo, ažurirajte svoju verziju baze podataka",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Molimo promijenite dozvole na 0770 tako da se tim direktorijem ne mogu služiti drugi korisnici",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Molimo provjerite sadrži li podatkovni direktorij u svom korijenu datoteku \".ocdata\"",
    "Could not obtain lock type %d on \"%s\"." : "Nije moguće dobiti lock tip %d na \"%s\"."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> owncloud-10.0.10.tgz: owncloud/lib/l10n/hr.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Pisanje u \"config\" direktoriju nije moguće!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Ovo se obično može popraviti tako da se Web poslužitelju dopusti pristup za pisanje u config direktoriju",
    "See %s" : "Vidite %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Ovo se obično može popraviti %sdavanjem pristupa web poslužitelju za pisanje u config direktoriju%s.",
    "Sample configuration detected" : "Nađena ogledna konfiguracija",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Otkriveno je da je ogledna konfiguracija kopirana. To može vašu instalaciju prekinuti i nije podržano.Molimo pročitajte dokumentaciju prije nego li izvršite promjene na config.php",
    "PHP %s or higher is required." : "PHP verzija treba biti %s ili viša.",
    "PHP with a version lower than %s is required." : "PHP sa verzijom manjom od %s je potrebna.",
    "Following databases are supported: %s" : "Sljedece baza podataka je podrzana: %s",
    "The library %s is not available." : "Knjiznica %s nije dostupna.",
    "Following platforms are supported: %s" : "Sljedece platforme su podrzane: %s",
    "ownCloud %s or higher is required." : "ownCloud %s ili visi je potreban.",
    "Unknown filetype" : "Vrsta datoteke nepoznata",
    "Invalid image" : "Neispravna slika",
    "today" : "Danas",
    "yesterday" : "Jučer",
    "last month" : "Prošli mjesec",
    "_%n month ago_::_%n months ago_" : ["prije %n mjeseca","prije %n mjeseci","prije %n mjeseci"],
    "last year" : "Prošle godine",
    "_%n hour ago_::_%n hours ago_" : ["prije %n sata","prije %n sati","prije %n sati"],
    "_%n minute ago_::_%n minutes ago_" : ["prije %n minute","prije %n minuta","prije %n minuta"],
    "seconds ago" : "prije par sekundi",
    "None" : "Ništa",
    "Username" : "Korisničko ime",
    "Password" : "Lozinka",
    "App directory already exists" : "Direktorij aplikacije već postoji",
    "Can't create app folder. Please fix permissions. %s" : "Nije moguće kreirati mapu aplikacija. molimo popravite dozvole. %s",
    "No source specified when installing app" : "Pri instaliranju aplikacija nijedan izvor nije specificiran",
    "No href specified when installing app from http" : "Pri instaliranju aplikacija iz http nijedan href nije specificiran.",
    "No path specified when installing app from local file" : "Pri instaliranju aplikacija iz lokalne datoteke nijedan put nije specificiran.",
    "Archives of type %s are not supported" : "Arhive tipa %s nisu podržane",
    "Failed to open archive when installing app" : "Otvaranje arhive pri instaliranju aplikacija nije uspjelo.",
    "App does not provide an info.xml file" : "Aplikacija ne pruža info.xml datoteku",
    "App can't be installed because of not allowed code in the App" : "Aplikaciju nije moguće instalirati zbog nedopuštenog koda u njoj.",
    "App can't be installed because it is not compatible with this version of ownCloud" : "Aplikaciju nije moguće instalirati jer nije kompatibilna s ovom verzijom ownClouda.",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Aplikaciju nije moguće instalirati jer sadrži oznaku <otpremljeno>istinito</otpremljeno>.",
    "Apps" : "Aplikacije",
    "General" : "Općenito",
    "Security" : "Sigurnost",
    "Encryption" : "Šifriranje",
    "Sharing" : "Dijeljenje zajedničkih resursa",
    "Search" : "pretraži",
    "Updates" : "nadogradnje",
    "%s enter the database username." : "%s unesite naziva korisnika baze podataka.",
    "%s enter the database name." : "%s unesite naziv baze podataka",
    "%s you may not use dots in the database name" : "%s ne smijete koristiti točke u nazivu baze podataka",
    "Oracle connection could not be established" : "Vezu Oracle nije moguće uspostaviti",
    "Oracle username and/or password not valid" : "Korisničko ime i/ili lozinka Oracle neispravni",
    "DB Error: \"%s\"" : "DB pogreška: \"%s\"",
    "Offending command was: \"%s\"" : "Neispravna naredba je bila: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Trebate unijeti neki postojeći račun ili administratora.",
    "Offending command was: \"%s\", name: %s, password: %s" : "Neispravna naredba je bila: \"%s\", ime: %s, lozinka: %s",
    "PostgreSQL username and/or password not valid" : "Korisničko ime i/ili lozinka PostgreSQL neispravni",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X nije podržan i %s na ovoj platformi neće raditi kako treba.",
    "For the best results, please consider using a GNU/Linux server instead." : "Za najbolje rezultate, molimo razmotrite mogućnost korištenje poslužitelja GNU/Linux.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Molimo uklonite postavke za open_basedir setting iz datoteke php.ini ili se prebacite na 64-bitni PHP.",
    "Set an admin username." : "Navedite admin korisničko ime.",
    "Set an admin password." : "Navedite admin lozinku.",
    "Can't create or write into the data directory %s" : "Ne moze se kreirati ili napisati u imenik podataka %s",
    "%s shared »%s« with you" : "%s je s vama podijelio »%s«",
    "Sharing %s failed, because the file does not exist" : "Dijeljenje %s nije uspjelo jer ta datoteka ne postoji",
    "You are not allowed to share %s" : "Nije vam dopušteno dijeliti %s",
    "Sharing %s failed, because the user %s does not exist" : "Dijeljenje %s nije uspjelo jer korisnik %s ne postoji",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Dijeljenje %s nije uspjelo jer korisnik %s nije član niti jedne grupe u kojoj je %s član",
    "Sharing %s failed, because this item is already shared with %s" : "Dijeljenje %s nije uspjelo jer je ova stavka već podijeljena s %s",
    "Sharing %s failed, because the group %s does not exist" : "Dijeljenje %s nije uspjelo jer grupa %s ne postoji",
    "Sharing %s failed, because %s is not a member of the group %s" : "Dijeljenje %s nije uspjelo jer %s nije član grupe %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Da biste kreirali javnu vezu, morate navesti lozinku, samo zaštićene veze su dopuštene.",
    "Sharing %s failed, because sharing with links is not allowed" : "Dijeljenje %s nije uspjelo jer dijeljenje s vezama nije dopušteno.",
    "Share type %s is not valid for %s" : "Tip dijeljenja %s nije dopušteni tip za %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Postavke dozvola za %s nisu uspjele jer dozvole premašuju dozvole za koje %s ima odobrenje",
    "Setting permissions for %s failed, because the item was not found" : "Postavke dozvola za %s nisu uspjele jer stavka nije nađena.",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Nije moguće postaviti datum isteka. Nakon što su podijeljeni, resursi ne mogu isteći kasnije nego %s ",
    "Cannot set expiration date. Expiration date is in the past" : "Nije moguće postaviti datum isteka. Datum isteka je u prošlosti",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Dijeljenje pozadine %s mora implementirati sučelje OCP\\Share_Backend",
    "Sharing backend %s not found" : "Dijeljenje pozadine %s nije nađeno",
    "Sharing backend for %s not found" : "Dijeljenje pozadine za %s nije nađeno",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Dijeljenje %s nije uspjelo jer dozvole premašuju dozvole za koje %s ima odobrenje.",
    "Sharing %s failed, because resharing is not allowed" : "Dijeljenje %s nije uspjelo jer ponovno dijeljenje nije dopušteno.",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Dijeljenje %s nije uspjelo jer pozadina za %s nije mogla pronaći svoj izvor",
    "Sharing %s failed, because the file could not be found in the file cache" : "Dijeljenje %s nije uspjelo jer u predmemoriji datoteke datoteka nije nađena.",
    "Could not find category \"%s\"" : "Kategorija \"%s\" nije nađena",
    "A valid username must be provided" : "Nužno je navesti ispravno korisničko ime",
    "A valid password must be provided" : "Nužno je navesti ispravnu lozinku",
    "The username is already being used" : "Korisničko ime se već koristi",
    "Help" : "Pomoć",
    "Settings" : "Postavke",
    "Users" : "Korisnici",
    "web services under your control" : "web usluge pod vašom kontrolom",
    "Application is not enabled" : "Aplikacija nije aktivirana",
    "Authentication error" : "Pogrešna autentikacija",
    "Token expired. Please reload page." : "Token je istekao. Molimo, ponovno učitajte stranicu.",
    "Unknown user" : "Korisnik nepoznat",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Pogonski programi baze podataka (sqlite, mysql, ili postgresql) nisu instalirani.",
    "Cannot write into \"config\" directory" : "Nije moguće zapisivati u \"config\" direktorij",
    "Cannot write into \"apps\" directory" : "Nije moguće zapisivati u \"apps\" direktorij",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Ovo se obično može popraviti %sdavanjem pristupa web poslužitelju za pisanje u apps direktorij%sili isključivanjem appstorea u konfiguracijskoj datoteci.",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Dozvole se obično mogu popraviti %sdavanjem pristupa web poslužitelju za pisanje u korijenskom direktoriju%s",
    "Setting locale to %s failed" : "Postavljanje regionalne sheme u %s nije uspjelo",
    "Please install one of these locales on your system and restart your webserver." : "Molimo instalirajte jednu od ovih regionalnih shema u svoj sustav i ponovno pokrenite svoj web poslužitelj.",
    "Please ask your server administrator to install the module." : "Molimo zamolite svog administratora poslužitelja da instalira modul.",
    "PHP module %s not installed." : "PHP modul %s nije instaliran.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Uzrok tome je vjerojatno neki ubrzivač predmemoriranja kao što je Zend OPcache ilieAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP moduli su instalirani, ali još uvijek su na popisu onih koji nedostaju?",
    "Please ask your server administrator to restart the web server." : "Molimo zamolite  svog administratora poslužitelja da ponovno pokrene web poslužitelj.",
    "PostgreSQL >= 9 required" : "Potreban je PostgreSQL >= 9",
    "Please upgrade your database version" : "Molimo, ažurirajte svoju verziju baze podataka",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Molimo promijenite dozvole na 0770 tako da se tim direktorijem ne mogu služiti drugi korisnici",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Molimo provjerite sadrži li podatkovni direktorij u svom korijenu datoteku \".ocdata\"",
    "Could not obtain lock type %d on \"%s\"." : "Nije moguće dobiti lock tip %d na \"%s\".",
    "Imprint" : "Otisak",
    "__language_name__" : "__jezik_naziv___"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
